@@ -1,15 +1,6 @@
 #!/bin/sh
-# This script will create the following tarballs:
-# llvm-toolchain-snapshot-3.2_3.2repack.orig-clang.tar.bz2
-# llvm-toolchain-snapshot-3.2_3.2repack.orig-clang-extra.tar.bz2
-# llvm-toolchain-snapshot-3.2_3.2repack.orig-compiler-rt.tar.bz2
-# llvm-toolchain-snapshot-3.2_3.2repack.orig-lld.tar.bz2
-# llvm-toolchain-snapshot-3.2_3.2repack.orig-lldb.tar.bz2
-# llvm-toolchain-snapshot-3.2_3.2repack.orig-polly.tar.bz2
-# llvm-toolchain-snapshot-3.2_3.2repack.orig-openmp.tar.bz2
-# llvm-toolchain-snapshot-3.2_3.2repack.orig-libcxx.tar.bz2
-# llvm-toolchain-snapshot-3.2_3.2repack.orig-libcxxabi.tar.bz2
-# llvm-toolchain-snapshot-3.2_3.2repack.orig.tar.bz2
+# This script will create the following tarball:
+# llvm-toolchain-XX_XX\~+20200120101212+de4b2a7fad6.orig.tar.xz
 
 set -e
 
@@ -140,12 +131,13 @@ if test -z  "$TAG" -a -z "$FINAL_RELEASE"; then
         # In general, in Debian, we will keep X until X.0.1 is released (or rc in experimental)
         # However, on apt.llvm.org, we will update the version to have X.0.1
         # This code is doing that.
-        CURRENT_VERSION="$(grep -oP 'set\(\s*LLVM_VERSION_(MAJOR|MINOR|PATCH)\s\K[0-9]+' llvm/CMakeLists.txt | paste -sd '.')"
+        CURRENT_VERSION="$(grep -oP 'set\(\s*LLVM_VERSION_(MAJOR|MINOR|PATCH)\s\K[0-9]+' cmake/Modules/LLVMVersion.cmake | paste -sd '.')"
     fi
     # the + is here to make sure that this version is considered more recent than the svn
     # dpkg --compare-versions 10~svn374977-1~exp1 lt 10~+2019-svn374977-1~exp1
     # to verify that
     VERSION="${CURRENT_VERSION}~++$(date +'%Y%m%d%I%M%S')+$(git log -1 --pretty=format:'%h')"
+    echo "CURRENT = ${CURRENT_VERSION}"
 else
 
     if ! echo "$EXACT_VERSION"|grep -q "$MAJOR_VERSION"; then
@@ -164,15 +156,16 @@ else
 fi
 
 # cleanup
-rm -rf */www/
+rm -rf */www/ build/ build-llvm/
 
 cd ../
 BASE="llvm-toolchain-${MAJOR_VERSION}_${VERSION}"
 FILENAME="${BASE}.orig.tar.xz"
-
 cp -R llvm-toolchain-integration-test-suite llvm-project/integration-test-suite
+# Argument to compress faster (for the cost of time)
+export XZ_OPT="-4 -T$(nproc)"
 echo "Compressing to $FILENAME"
-tar Jcf $CURRENT_PATH/"$FILENAME" --exclude .git --transform="s|llvm-project|$BASE|" -C $EXPORT_PATH llvm-project
+time tar Jcf $CURRENT_PATH/"$FILENAME" --exclude .git --exclude .gitattributes --exclude .git-blame-ignore-revs --exclude .gitignore --exclude .github --exclude build-llvm --transform="s|llvm-project|$BASE|" -C $EXPORT_PATH llvm-project
 rm -rf llvm-project/integration-test-suite
 
 export DEBFULLNAME="Sylvestre Ledru"
